@@ -386,6 +386,14 @@ struct _VteTerminalPrivate {
 
         /* Style stuff */
         GtkBorder inner_border;
+
+#if GTK_CHECK_VERSION (2, 91, 2)
+        /* GtkScrollable impl */
+        GtkAdjustment *hadjustment; /* unused */
+        guint hscroll_policy : 1; /* unused */
+
+        guint vscroll_policy : 1;
+#endif
 };
 
 
