@@ -1074,6 +1074,16 @@ main(int argc, char **argv)
 			g_warning (_("Could not parse the geometry spec passed to --geometry"));
 		}
 	}
+#if GTK_CHECK_VERSION(2, 91, 0)
+	else {
+		/* As of GTK+ 2.91.0, the default size of a window comes from its minimum
+		 * size not its natural size, so we need to set the right default size
+		 * explicitly */
+		gtk_window_set_default_geometry (GTK_WINDOW (window),
+						 vte_terminal_get_column_count (terminal),
+						 vte_terminal_get_row_count (terminal));
+	}
+#endif
 
 	gtk_widget_show_all(window);
 
